@@ -217,7 +217,11 @@ notFoundErr env modName reason =
              }
         LookupUnusable unusable ->
           let unusables' = map get_unusable unusable
+#if MIN_VERSION_ghc(9,6,4) && !MIN_VERSION_ghc(9,8,1)
+              get_unusable (m, ModUnusable r) = r
+#else
               get_unusable (m, ModUnusable r) = (moduleUnit m, r)
+#endif
               get_unusable (_, r) =
                 pprPanic "findLookupResult: unexpected origin" (ppr r)
            in notFound {fr_unusables = unusables'}
